summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/ui/kopetelistviewitem.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/ui/kopetelistviewitem.h')
-rw-r--r--kopete/libkopete/ui/kopetelistviewitem.h85
1 files changed, 43 insertions, 42 deletions
diff --git a/kopete/libkopete/ui/kopetelistviewitem.h b/kopete/libkopete/ui/kopetelistviewitem.h
index 77d06540..ac19c4b8 100644
--- a/kopete/libkopete/ui/kopetelistviewitem.h
+++ b/kopete/libkopete/ui/kopetelistviewitem.h
@@ -1,5 +1,5 @@
/*
- kopetelistviewitem.h - Kopete's modular QListViewItems
+ kopetelistviewitem.h - Kopete's modular TQListViewItems
Copyright (c) 2005 by Engin AYDOGAN <engin@bzzzt.biz>
Copyright (c) 2004 by Richard Smith <kde@metafoo.co.uk>
@@ -44,9 +44,9 @@ public:
Component *componentAt( const TQPoint &pt );
/** Repaint this item */
- virtual void repaint() = 0;
- /** Relayout this item */
- virtual void relayout() = 0;
+ virtual void tqrepaint() = 0;
+ /** Retqlayout this item */
+ virtual void retqlayout() = 0;
/**
* Get the tool tip string and rectangle for a tip request at position
@@ -64,7 +64,7 @@ protected:
virtual void componentRemoved( Component *component );
/** A child item has been resized */
virtual void componentResized( Component *component );
- /** Remove all children */
+ /** Remove all tqchildren */
virtual void clear();
/** @internal animate items */
@@ -102,7 +102,7 @@ public:
class Component : public ComponentBase
{
protected:
- Component( ComponentBase *parent );
+ Component( ComponentBase *tqparent );
public:
virtual ~Component() = 0;
@@ -110,18 +110,18 @@ public:
* Set the size and position of this item relative to the list view item. Should
* only be called by the containing item.
* @param rect the new rectangle this component will paint in, relative to the painter
* passed to the paint() function by the parent item.
*/
- virtual void layout( const TQRect &rect );
+ virtual void tqlayout( const TQRect &rect );
/**
* Paint this item, inside the rectangle returned by rect().
- * The default implementation calls paint on all children.
+ * The default implementation calls paint on all tqchildren.
*/
virtual void paint( TQPainter *painter, const TQColorGroup &cg );
- void repaint();
- void relayout();
+ void tqrepaint();
+ void retqlayout();
/**
* @return the rect this component was allocated last time it was laid out
@@ -181,8 +181,8 @@ public:
/**
* RTTI: Runtime Type Information
- * Exactly the same as Qt's approach to identify types of
- * QCanvasItems.
+ * Exactly the same as TQt's approach to identify types of
+ * TQCanvasItems.
*/
enum RttiValues {
@@ -196,20 +196,20 @@ public:
protected:
/**
* Change the minimum width, in pixels, this component requires in order
* to be at all useful. Note: do not call this from your layout() function.
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
* the existing values. if it returns true, you do not need to relayout,
* since the parent component will do that for you.
*/
bool setMinWidth( int width );
/**
* Change the minimum height, in pixels, this component requires in order
* to be at all useful. Note: do not call this from your layout() function.
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
* the existing values. If it returns true, you do not need to relayout,
* since the parent component will do that for you.
*/
bool setMinHeight( int height );
@@ -232,11 +232,11 @@ private:
class BoxComponent : public Component
{
public:
- enum Direction { Horizontal, Vertical };
- BoxComponent( ComponentBase *parent, Direction dir = Horizontal );
+ enum Direction {Horizontal,Vertical };
+ BoxComponent( ComponentBase *tqparent, Direction dir =Horizontal );
~BoxComponent();
- virtual void layout( const TQRect &rect );
+ virtual void tqlayout( const TQRect &rect );
virtual int widthForHeight( int height );
virtual int heightForWidth( int width );
@@ -262,12 +262,12 @@ private:
class ContactBoxComponent : public BoxComponent
{
public:
- ContactBoxComponent(ComponentBase *parent, Direction dir = Horizontal);
+ ContactBoxComponent(ComponentBase *tqparent, Direction dir =Horizontal);
~ContactBoxComponent();
virtual void reloadTheme();
- virtual void layout(const TQRect &rect);
+ virtual void tqlayout(const TQRect &rect);
virtual int widthForHeight(int height);
virtual int heightForWidth(int width);
@@ -285,12 +285,12 @@ private:
class GroupBoxComponent : public BoxComponent
{
public:
- GroupBoxComponent(ComponentBase *parent, Direction dir = Horizontal);
+ GroupBoxComponent(ComponentBase *tqparent, Direction dir =Horizontal);
~GroupBoxComponent();
virtual void reloadTheme();
- virtual void layout(const TQRect &rect);
+ virtual void tqlayout(const TQRect &rect);
virtual int widthForHeight(int height);
virtual int heightForWidth(int width);
@@ -305,7 +305,7 @@ private:
class TextComponent : public Component
{
public:
- TextComponent( ComponentBase *parent, const TQFont &font = TQFont(), const TQString &text = TQString::null );
+ TextComponent( ComponentBase *tqparent, const TQFont &font = TQFont(), const TQString &text = TQString() );
~TextComponent();
TQString text();
@@ -335,8 +335,8 @@ private:
class ImageComponent : public Component
{
public:
- ImageComponent( ComponentBase *parent );
- ImageComponent( ComponentBase *parent, int minW, int minH );
+ ImageComponent( ComponentBase *tqparent );
+ ImageComponent( ComponentBase *tqparent, int minW, int minH );
~ImageComponent();
virtual void setPixmap( const TQPixmap &img, bool adjustSize = true);
@@ -344,7 +344,7 @@ public:
virtual void paint( TQPainter *painter, const TQColorGroup &cg );
- virtual void scale( int w, int h, TQImage::ScaleMode );
+ virtual void scale( int w, int h, TQ_ScaleMode );
static int RTTI;
virtual int rtti() const { return RTTI; }
protected:
@@ -358,8 +358,8 @@ protected:
class FaceComponent : public ImageComponent
{
public:
- FaceComponent(ComponentBase *parent): ImageComponent(parent) {}
- FaceComponent(ComponentBase *parent, int minW, int minH): ImageComponent(parent, minH, minW) {}
+ FaceComponent(ComponentBase *tqparent): ImageComponent(tqparent) {}
+ FaceComponent(ComponentBase *tqparent, int minW, int minH): ImageComponent(tqparent, minH, minW) {}
void setPixmap(const TQPixmap &img, bool adjustSize = true);
void paint(TQPainter *painter, const TQColorGroup &cg);
@@ -371,7 +371,7 @@ public:
class ContactComponent : public ImageComponent
{
public:
- ContactComponent( ComponentBase *parent, Kopete::Contact *contact, int iconSize);
+ ContactComponent( ComponentBase *tqparent, Kopete::Contact *contact, int iconSize);
~ContactComponent();
void updatePixmap();
Kopete::Contact *contact();
@@ -387,7 +387,7 @@ protected:
class SpacerComponent : public Component
{
public:
- SpacerComponent( ComponentBase *parent, int w, int h );
+ SpacerComponent( ComponentBase *tqparent, int w, int h );
};
/**
@@ -400,13 +400,13 @@ public:
/**
* Constructor
*/
- DisplayNameComponent( ComponentBase *parent );
+ DisplayNameComponent( ComponentBase *tqparent );
/**
* Dtor
*/
~DisplayNameComponent();
- void layout( const TQRect& rect );
+ void tqlayout( const TQRect& rect );
TQString text();
void setText( const TQString& text );
@@ -428,7 +428,7 @@ private:
class HSpacerComponent : public Component
{
public:
- HSpacerComponent( ComponentBase *parent );
+ HSpacerComponent( ComponentBase *tqparent );
int widthForHeight( int );
static int RTTI;
@@ -438,7 +438,7 @@ public:
class VSpacerComponent : public Component
{
public:
- VSpacerComponent( ComponentBase *parent );
+ VSpacerComponent( ComponentBase *tqparent );
int heightForWidth( int );
static int RTTI;
@@ -454,13 +454,14 @@ public:
class Item : public TQObject, public KListViewItem, public ComponentBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- Item( TQListView *parent, TQObject *owner = 0, const char *name = 0 );
- Item( TQListViewItem *parent, TQObject *owner = 0, const char *name = 0 );
+ Item( TQListView *tqparent, TQObject *owner = 0, const char *name = 0 );
+ Item( TQListViewItem *tqparent, TQObject *owner = 0, const char *name = 0 );
~Item();
- void repaint();
- void relayout();
+ void tqrepaint();
+ void retqlayout();
void setup();
virtual void paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int align );
@@ -110,18 +110,18 @@ public:
* only be called by the containing item.
* @param rect the new rectangle this component will paint in, relative to the painter
- * passed to the paint() function by the parent item.
+ * passed to the paint() function by the tqparent item.
*/
@@ -196,20 +196,20 @@ public:
/**
* Change the minimum width, in pixels, this component requires in order
- * to be at all useful. Note: do not call this from your layout() function.
+ * to be at all useful. Note: do not call this from your tqlayout() function.
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
@@ -196,20 +196,20 @@ public:
* @param width the minimum width
* @return true if the size has actually changed, false if it's been set to
- * the existing values. if it returns true, you do not need to relayout,
- * since the parent component will do that for you.
+ * the existing values. if it returns true, you do not need to retqlayout,
+ * since the tqparent component will do that for you.
*/
bool setMinWidth( int width );
@@ -196,20 +196,20 @@ public:
/**
* Change the minimum height, in pixels, this component requires in order
- * to be at all useful. Note: do not call this from your layout() function.
+ * to be at all useful. Note: do not call this from your tqlayout() function.
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
@@ -196,20 +196,20 @@ public:
* @param height the minimum height
* @return true if the size has actually changed, false if it's been set to
- * the existing values. If it returns true, you do not need to relayout,
- * since the parent component will do that for you.
+ * the existing values. If it returns true, you do not need to retqlayout,
+ * since the tqparent component will do that for you.
*/
bool setMinHeight( int height );